.. _manual:

***********************
Cytoflow program manual
***********************

.. note:: **The user manual is currently under construction.**  You can get
   help for each operation and view by looking at the *Help* pane in the
   user interface after you select it.  If the help pane is hidden, you 
   can show it in the *View* menu.

.. toctree::
   :maxdepth: 2
   :numbered:

   manual/01_quickstart
